@@ -2,5 +2,5 @@ __all__ = ["ServerError"]
 
 
 class ServerError(Exception):
-    def __init__(self, message):
+    def __init__(self, message: str):
         self.message = message
