@@ -1,7 +1,8 @@
-from smile_id_core.Utilities import Utilities
 from smile_id_core.IdApi import IdApi
-from smile_id_core.WebApi import WebApi
-from smile_id_core.Signature import Signature
 from smile_id_core.ServerError import ServerError
+from smile_id_core.Signature import Signature
+from smile_id_core.Utilities import Utilities, get_version
+from smile_id_core.WebApi import WebApi
 
+__version__ = get_version()
 __all__ = ["IdApi", "Signature", "Utilities", "WebApi", "ServerError"]
